pipolars.SummaryType - PIPolars 0.1.0 documentation

Skip to content
Back to top
View this page
Edit this page

# pipolars.SummaryType

class pipolars.SummaryType

  Bases: `IntEnum`

  Summary calculation types for PI data.

  These correspond to OSIsoft AF SDK AFSummaryTypes enumeration.

  __init__(*args, **kwds)

  Methods

  `conjugate`() | Returns self, the complex conjugate of any int.
  `bit_length`() | Number of bits necessary to represent self in binary.
  `bit_count`() | Number of ones in the binary representation of the absolute value of self.
  `to_bytes`([length, byteorder, signed]) | Return an array of bytes representing an integer.
  `from_bytes`(bytes[, byteorder, signed]) | Return the integer represented by the given array of bytes.
  `as_integer_ratio`() | Return a pair of integers, whose ratio is equal to the original int.
  `is_integer`() | Returns True.
  `__init__`(*args, **kwds) |

  Attributes

  `real` | the real part of a complex number
  `imag` | the imaginary part of a complex number
  `numerator` | the numerator of a rational number in lowest terms
  `denominator` | the denominator of a rational number in lowest terms
  `NONE` |
  `TOTAL` |
  `AVERAGE` |
  `MINIMUM` |
  `MAXIMUM` |
  `RANGE` |
  `STD_DEV` |
  `POP_STD_DEV` |
  `COUNT` |
  `PERCENT_GOOD` |
  `TOTAL_WITH_UOM` |
  `ALL` |
  `ALL_FOR_NON_NUMERIC` |

  NONE = 0
  TOTAL = 1
  AVERAGE = 2
  MINIMUM = 4
  MAXIMUM = 8
  RANGE = 16
  STD_DEV = 32
  POP_STD_DEV = 64
  COUNT = 128
  PERCENT_GOOD = 8192
  TOTAL_WITH_UOM = 16384
  ALL = 24831
  ALL_FOR_NON_NUMERIC = 8320
  __new__(value)